# Server configuration generated from template
[Interface]
Address = {{ server_ip }}/24
ListenPort = {{ listen_port }}
PrivateKey = {{ server_private_key }}
{% if post_up_rules and post_down_rules %}
PostUp = {{ post_up_rules | join('; ') }}
PostDown = {{ post_down_rules | join('; ') }}
{% endif %}

{% for peer in peers %}
[Peer]
PublicKey = {{ peer.public_key }}
AllowedIPs = {{ peer.ip }}/32
{% endfor %}
